<template>
  <a-card :bordered="false">
    <!-- 查询区域 -->
    <div class="table-page-search-wrapper">
      <a-form layout="inline" @keyup.enter.native="searchQuery">
        <a-row :gutter="24">
          <a-col :md="4" :sm="4">
            <a-form-item label="停机类型">
              <a-radio-group v-model="queryParam.downtimeType" placeholder="请选择停机类型" @change="searchQuery">
                <a-radio :value="0">计划停机</a-radio>
                <a-radio :value="1">非计划停机</a-radio>
              </a-radio-group>
            </a-form-item>
          </a-col>

          <a-col :md="5" :sm="5">
            <a-form-item label="停机原因描述">
              <a-input v-model="queryParam.downtimeDescription" placeholder="请输入停机原因"/>
            </a-form-item>
          </a-col>

          <a-col :md="4" :sm="4">
            <a-space>
              <a-button type="primary" @click="searchQuery" icon="search">查询</a-button>
              <a-button type="primary" @click="searchReset" icon="reload">重置</a-button>
            </a-space>
          </a-col>
        </a-row>
      </a-form>
    </div>

    <!-- 操作按钮区域 -->
    <div class="table-operator">
      <a-button @click="handleAdd" type="primary" icon="plus">新增</a-button>
      <a-dropdown v-if="selectedRowKeys.length > 0">
        <a-menu slot="overlay" @click="handleMenuClick">
          <a-menu-item key="1">
            <a-icon type="delete" @click="batchDel"/>
            删除
          </a-menu-item>
        </a-menu>
        <a-button style="margin-left: 8px">
          批量操作
          <a-icon type="down"/>
        </a-button>
      </a-dropdown>
    </div>

    <!-- table区域-begin -->
    <div>
      <div class="ant-alert ant-alert-info" style="margin-bottom: 16px;">
        <i class="anticon anticon-info-circle ant-alert-icon"></i>已选择&nbsp;<a style="font-weight: 600">{{
          selectedRowKeys.length
        }}</a>项&nbsp;&nbsp;
        <a style="margin-left: 24px" @click="onClearSelected">清空</a>
      </div>

      <a-table
        ref="table"
        bordered
        size="middle"
        rowKey="id"
        :scroll="{x:'max-content',y:600}"
        :columns="columns"
        :dataSource="dataSource"
        :pagination="ipagination"
        :loading="loading"
        :rowSelection="{selectedRowKeys: selectedRowKeys, onChange: onSelectChange}"
        @change="handleTableChange">
        <template slot="downtimeType" slot-scope="text">
          {{ text === 0 ? '计划停机' : '非计划停机' }}
        </template>

        <template slot="action" slot-scope="text, record">
          <a @click="handleEdit(record)">编辑</a>

          <a-divider type="vertical"/>

          <a-popconfirm title="确定删除吗?" @confirm="() => handleDelete(record.id)">
            <a>删除</a>
          </a-popconfirm>
        </template>
      </a-table>
    </div>
    <!-- table区域-end -->

    <EquipmentShutDownReasonModal ref="modalForm" @ok="modalFormOk"/>
  </a-card>
</template>

<script>
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import EquipmentShutDownReasonModal from '@views/mdc/base/modules/EquipmentShutDownReasonList/EquipmentShutDownReasonModal.vue'

export default {
  name: 'EquipmentShutDownReasonList',
  mixins: [JeecgListMixin],
  components: {
    EquipmentShutDownReasonModal
  },
  data() {
    return {
      queryParam: {},
      /* 分页参数 */
      ipagination: {
        current: 1,
        pageSize: 30,
        pageSizeOptions: ['30', '50', '100'],
        showTotal: (total, range) => {
          return range[0] + '-' + range[1] + ' 共' + total + '条'
        },
        showQuickJumper: true,
        showSizeChanger: true,
        total: 0
      },
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 60,
          align: 'center',
          customRender: function(t, r, index) {
            return parseInt(index) + 1
          }
        },
        {
          title: '停机原因',
          align: 'center',
          width: 350,
          dataIndex: 'downtimeDescription'
        },
        {
          title: '停机类型',
          align: 'center',
          scopedSlots: { customRender: 'downtimeType' },
          dataIndex: 'downtimeType',
          width: 350
        },
        {
          title: '备注',
          align: 'center',
          dataIndex: 'remark',
          width: 350
        },
        {
          title: '操作',
          dataIndex: 'action',
          scopedSlots: { customRender: 'action' },
          align: 'center',
          width: 150
        }
      ],
      url: {
        list: '/mdc/mdcDowntimeReason/list',
        delete: '/mdc/mdcDowntimeReason/delete',
        deleteBatch: '/mdc/mdcDowntimeReason/deleteBatch'
      }
    }
  },
  methods: {
    handleMenuClick(e) {
      if (e.key == 1) {
        this.batchDel()
      }
    }
  }

}
</script>